<?php

namespace App\Http\Controllers;
use App\Models\Blending;
use App\Models\Ingreso;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;

class BlendingController extends Controller
{
    /**
     * Display a listing of the resource.
        */
        public function __construct()
        { 
            $this->middleware('permission:ver balanza');
        }
        public function index()
        {
            $blendings = Blending::all();
            $ingresos = Ingreso::all();
            return view('blendings.index', compact('blendings', 'ingresos'));
        }
    
        public function create()
            {
                // Obtener los ingresos que no están en un blending
                $ingresos = Ingreso::whereNotIn('id', function ($query) {
                    $query->select('ingreso_id')
                        ->from('blending_ingreso') // Cambia esto según el nombre de tu tabla intermedia
                        ->distinct();
                })->get();
                $lotesRegistrados = Ingreso::pluck('lote')->unique()->toArray();

                return view('blendings.create', compact('ingresos', 'lotesRegistrados'));
            }

            public function store(Request $request)
            {
                $request->validate([
                    'lista' => 'required',
                    'cod' => 'nullable|string',
                    'notas' => 'nullable|string',
                    'ingresos' => 'required|array',
                    'ingresos.*' => 'exists:ingresos,id',
                    'lote' => 'required|integer', // Añade la validación para el lote
                    'pesoblending' => 'required|numeric',
                ]);
            
                try {
                    DB::beginTransaction();
            
                    $ingresos = Ingreso::whereIn('id', $request->ingresos)->get();
                    
                    $blending = Blending::create([
                        'cod' => $request->cod,
                        'lista' => $request->lista,
                        'notas' => $request->notas,
                        'pesoblending' => $ingresos->sum('peso_total'), 
                        'user_id' => auth()->id(),
                        'detalles' => json_encode($ingresos), 
                    ]);
            
                    // Actualiza la fase a BLENDING y establece el lote
                    Ingreso::whereIn('id', $request->ingresos)->update(['fase' => 'BLENDING', 'lote' => $request->lote]); // Asigna el lote aquí
                    $blending->ingresos()->attach($ingresos->pluck('id'));
            
                    DB::commit();
                    return redirect()->route('blendings.index')->with('success', 'Blending creado con éxito.');
                } catch (\Exception $e) {
                    DB::rollBack();
                    Log::error('Error creating blending: ' . $e->getMessage()); // Log the error
                    return redirect()->back()->withErrors(['error' => 'Ocurrió un error al crear el blending.']);
                }
            }
            

        

    public function show($id)
        {
            $blending = Blending::with('ingresos')->findOrFail($id); // Cargar el blending con los ingresos asociados
            return view('blendings.show', compact('blending'));
        }

        public function edit($id)
        {
            // Obtener el blending que se está editando, incluyendo los ingresos asociados
            $blending = Blending::with('ingresos')->findOrFail($id);
        
            // Obtener los IDs de los ingresos que ya están en un blending
            $ingresosUsados = Blending::with('ingresos')->get()->flatMap(function ($blending) {
                return $blending->ingresos->pluck('id');
            })->toArray();
        
            // Obtener los ingresos que no están en un blending
            $ingresos = Ingreso::whereNotIn('id', $ingresosUsados)->get();
        
            // Obtener los lotes registrados desde los ingresos no utilizados
            $lotesRegistrados = $ingresos->pluck('lote')->unique()->toArray();
        
            return view('blendings.edit', compact('blending', 'ingresos', 'lotesRegistrados'));
        }
        

    public function update(Request $request, $id)
    {
        // Validar los datos    
        $request->validate([
            'lista' => 'required|string|max:255',
            'cod' => 'required|string|max:100',
            'notas' => 'nullable|string',
        ]);

        // Encontrar el blending y actualizarlo
        $blending = Blending::findOrFail($id);
        $blending->lista = $request->lista; // Asignar nuevo valor
        $blending->notas = $request->notas; // Asignar nuevo valor
        $blending->save(); // Guardar cambios

        // Redirigir a la lista con un mensaje de éxito
        return redirect()->route('blendings.index')->with('success', 'Blending actualizado correctamente.');
    }   

    public function destroy(string $id)
    {
        // Iniciar una transacción
        DB::beginTransaction();
    
        try {
            // Buscar el blending por su ID
            $blending = Blending::with('ingresos')->findOrFail($id);
    
            // Obtener los IDs de los ingresos asociados
            $ingresosIds = $blending->ingresos->pluck('id');
    
            // Cambiar la fase de los ingresos asociados a "INGRESADO"
            Ingreso::whereIn('id', $ingresosIds)->update(['fase' => 'INGRESADO']);
    
            // Eliminar el blending
            $blending->delete();
    
            // Confirmar la transacción
            DB::commit();
    
            // Redireccionar con un mensaje
            return redirect()->route('blendings.index')->with('success', 'Blending eliminado y fase de ingresos actualizada exitosamente.');
        } catch (\Exception $e) {
            // Revertir la transacción en caso de error
            DB::rollBack();
    
            // Redireccionar con un mensaje de error
            return redirect()->back()->withErrors(['error' => 'Ocurrió un error al eliminar el blending.']);
        }
    }
    
    
}
