<?php

namespace App\Http\Controllers;
use App\Models\Despacho;
use App\Models\Blending;
use App\Models\Peso;
use App\Models\IngresoDespacho;
use Illuminate\Http\Request;

class DespachoController extends Controller
{
    public function index()
    {
        $despachos = Despacho::all();
       
        return view('despachos.index', compact('despachos'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create($blendingId)
{
    // Verificar si el blendingId existe y obtener los datos necesarios
    $blending = Blending::with('ingresos')->findOrFail($blendingId); // Obtener el blending con los ingresos relacionados

    // Obtener los datos de NroSalida, Bruto, Neto y Tara
    $NroSalida = Peso::select('NroSalida', 'Bruto', 'Neto', 'Tara')
                     ->orderBy('NroSalida', 'desc')
                     ->get();

    // Pasar los datos a la vista
    return view('despachos.create', compact('blending', 'NroSalida'));
}
    // Almacenar un nuevo despacho

    public function store(Request $request)
    {
        // Validar los datos del despacho
        $request->validate([
            'fecha' => 'required|date',
            'empresa' => 'required|string|max:255',
            'codigo' => 'required|string|max:255',
            'deposito' => 'required|string|max:255',
            'destino' => 'required|string|max:255',
            'ingresos_data' => 'required', // Validar los ingresos
        ]);

        // Crear el despacho en la tabla `despachos`
        $despacho = Despacho::create([
            'blending_id' => $request->blending_id,
            'fecha' => $request->fecha,
            'empresa' => $request->empresa,
            'codigo' => $request->codigo,
            'deposito' => $request->deposito,
            'destino' => $request->destino,
        ]);

        // Obtener los datos de los ingresos en formato JSON
        $ingresosData = json_decode($request->ingresos_data, true);

        // Crear los ingresos y asociarlos al despacho
        foreach ($ingresosData as $ingreso) {
            IngresoDespacho::create([
                'despacho_id' => $despacho->id, // Relacionamos el ingreso con el despacho
                'nro_salida' => $ingreso['NroSalida'],
                'precinto' => $ingreso['Precinto'],
                'guia' => $ingreso['Guia'],
                'bruto' => $ingreso['Bruto'],
                'tara' => $ingreso['Tara'],
                'neto' => $ingreso['Neto'],
                'tracto' => $ingreso['Tracto'],
                'carreta' => $ingreso['Carreta'],
            ]);
        }

        // Redirigir al usuario con un mensaje de éxito
        return redirect()->route('despachos.index')->with('success', 'Despacho y sus ingresos han sido guardados exitosamente.');
    }
    
    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
}
